<?php
/*
Plugin Name: Fast Image Adder
Plugin URI: http://www.robbyslaughter.com/
Description: Incredibly fast image uploading, without the need for an image dialog
Version: 2.0
Author: AccelaWork
Author URI: http://www.accelawwork.com/
*/

define("DEFAULT_WIDTH", 500);
define("DEFAULT_HTMLPATTERN",  
  '<img src="$1" class="aligncenter size-full" id="$2" alt="$3" width="$4" height="$5" /><br />&copy; $6 $7');

// Create the function to output the contents of our Dashboard Widget

/* Use the admin_menu action to define the custom boxes */
add_action('admin_menu', 'fastimageadder_add_custom_box');


/* Adds a custom section to the "advanced" Post and Page edit screens */
function fastimageadder_add_custom_box($post) {

  add_options_page('Fast Image Adder Options', 'Fast Image Adder', 'manage_options', 'fastimageadder', 'fastimageadder_options');

   
  if( function_exists( 'add_meta_box' )) {
    add_meta_box( 'fastimageadder_sectionid', __( 'Fast Image Adder', 'fastimageadder_textdomain' ), 
                'fastimageadder_inner_custom_box', 'post', 'normal', 'high' );
    add_meta_box( 'fastimageadder_sectionid', __( 'Fast Image Adder', 'fastimageadder_textdomain' ), 
                'fastimageadder_inner_custom_box', 'page', 'normal', 'high' );
   } else {
    add_action('dbx_post_advanced', 'fastimageadder_old_custom_box' );
    add_action('dbx_page_advanced', 'fastimageadder_old_custom_box' );
  }
}
   
function fastimageadder_options() {

  if (!current_user_can('manage_options'))  {
    wp_die( __('You do not have sufficient permissions to access this page.') );
  }
  
  // variables for the field and option names 
  $hidden_field_name = 'fastimageadder_submit_hidden';
  $opt_maxwidth = 'fastimageadder_maxwidth';
  $opt_featuredimg = 'fastimageadder_featuredimg';
  $opt_htmlpattern = 'fastimageadder_htmlpattern';

  // Read in existing option values from database
  $val_maxwidth = get_option($opt_maxwidth);
  $val_featuredimg = get_option($opt_featuredimg);
  $val_htmlpattern = (get_option($opt_htmlpattern));
  
  // Set default width of DEFAULT_WIDTH
  if ($val_maxwidth == "") { $val_maxwidth = DEFAULT_WIDTH; }

  // Set default width of DEFAULT_HTMLPATTERN;
  if ($val_htmlpattern == "") { $val_htmlpattern = DEFAULT_HTMLPATTERN; }
  
  // See if the user has posted us some information
  // If they did, this hidden field will be set to 'Y'
  if( isset($_POST[ $hidden_field_name ]) && $_POST[ $hidden_field_name ] == 'Y' ) {
     
    // Read their posted values
    $val_maxwidth = stripslashes($_POST[ $opt_maxwidth ]);
    $val_featuredimg = stripslashes($_POST[ $opt_featuredimg ]);
    $val_htmlpattern = stripslashes($_POST[ $opt_htmlpattern ]);
    
    // Make sure they haven't opted to reset the HTML pattern
    if ($val_htmlpattern == "") { $val_htmlpattern = DEFAULT_HTMLPATTERN; }

    // Save the posted values in the database
    update_option($opt_maxwidth, $val_maxwidth);
    update_option($opt_featuredimg, $val_featuredimg);
    update_option($opt_htmlpattern, $val_htmlpattern);

    // Put an settings updated message on the screen
    ?>
      <div class="updated"><p><strong><?php _e('Settings saved.', 'menu-test' ); ?></strong></p></div>
    <?php
   }

   // Now display the settings editing screen
  // $opt_val_converted = fast_image_adder_convert($opt_val);
   
   echo '<div class="wrap">';
   // header
   echo "<h2>" . __( 'Fast Image Adder Plugin Options', 'fast-image-adder' ) . "</h2>";
   
   ?>
     <p>
       The Fast Image Adder is an extremely simple tool that lets you upload and insert images into your posts
       in record time.
     </p>
     
     <p>
       Below you can configure the plugin. The code automatically resizes large images down to the 
       <strong>max image width</strong>. You can also set up your preferred HTML code for images, if you like
       fancy things like borders or captions.
     </p>
   <?php  
   
   // settings form
   ?>
   <form name="form1" method="post" action="">
      <input type="hidden" name="<?php echo $hidden_field_name; ?>" value="Y">
      
      <p>
        <strong>Maximum image width (pixels):</strong> <input size="4" type="text" name="<?php echo $opt_maxwidth; ?>" value="<?php echo $val_maxwidth; ?>"><br />
        <em>Should be no wider than the maximum width of your template. Larger images will be scaled down, smaller images will not be resized.</em>
      </p>
	  
      <p>
        <strong>Use as Featured Image (if not yet specified):</strong> <input type="checkbox" name="<?php echo $opt_featuredimg; ?>" <?php if($val_featuredimg) { echo "checked";} ?>><br />
        <em>Checking this box will add the resized image as featured image for the post. It will only do so if there is no featured image. The "title" will be used for the alt text as well.</em>
      </p>

      <p>
      <strong>HTML Pattern for image:</strong> <br />
      <em>$1 refers to the URL of the image, $2 refers to the filename of the image, $3 is the friendly name. $4 is width, $5 is height, $6 is a caption. $7 is the URL to the selected license. Leave the pattern blank to reset to the default.</em><br/> 
      <textarea style="width:100%; height:4em" name="<?php echo $opt_htmlpattern; ?>"><?php echo htmlentities($val_htmlpattern); ?></textarea>
      </p>
      
      <p class="submit">
      <input type="submit" name="Submit" class="button-primary" value="<?php esc_attr_e('Save Changes') ?>" />
      </p>
   </form>
      
   <hr />
      <h3>Test Area</h3>
      
      <p>After you've saved your changes above, try out your configuration of Fast Image Adder below. (Tests
        do not actually download and resize images.)</p>
      
      <div style="background:#ffffff; border:1px solid #cccccc; margin:10px; padding:10px;">
         <?php
           fastimageadder_inner_custom_box($post, true);
         ?>
      </div>

      <h3>Additional Information</h3>
      
      <p>
        The only component you must include is a valid URL to the original image. If you leave the name blank,
        one will be generated for you.
      </p>
      
      <p>
        These images are <em>not</em> added to your WordPress Media gallery. So, if you lose track of a URL, they
        will hang out in your Uploads directory unnoticed.
      </p>
      
      <h3>
        Example Patterns
      </h3>
      
      <h4>Photograph with Caption</h4>
      <code>
        &lt;div style=&quot;border:1px solid #777; padding:5px; margin:5px; text-align:center&quot;&gt;&lt;img src=&quot;$1&quot; class=&quot;aligncenter size-full&quot; id=&quot;$2&quot; alt=&quot;$3&quot; width=&quot;$4&quot; height=&quot;$5&quot; /&gt;&lt;strong&gt;$3&lt;/strong&gt;&lt;br /&gt;($4 x $5) - $6&lt;/div&gt;
      </code>        
      
      <h4>Centered Image</h4>
      <code>
        &lt;img src=&quot;$1&quot; class=&quot;aligncenter size-full&quot; id=&quot;$2&quot; alt=&quot;$3&quot; width=&quot;$4&quot; height=&quot;$5&quot; /&gt;
      </code>
      
      <h4>Pulled Out of The Way</h4>
      <code>
        &lt;div style=&quot;float:right; position:relative; left:$4px&quot;&gt;&lt;img src=&quot;$1&quot; class=&quot;aligncenter size-full&quot; id=&quot;$2&quot; alt=&quot;$3&quot; width=&quot;$4&quot; height=&quot;$5&quot; /&gt;&lt;/div&gt;      
      </code>
   </div>
<?php  
}

/* Prints the inner fields for the custom post/page section */
function fastimageadder_inner_custom_box($post, $test_mode = false) {

  // Use nonce for verification

  echo '<input type="hidden" name="fastimageadder_noncename" id="fastimageadder_noncename" value="' . 
    wp_create_nonce( plugin_basename(__FILE__) ) . '" />';

  // The actual fields for data entry
  ?>
  <script>
  function execute_fast_image_adder_upload()
  {
     document.getElementById("fast_image_adder_div").style.display = "none";
     document.getElementById("fast_image_adder_loading_icon").style.display = "block";
     document.getElementById("fast_image_adder_iframe").style.display = "block";
     document.getElementById("fast_image_adder_iframe").src = "<?php echo WP_PLUGIN_URL; ?>/fast-image-adder/fast-image-adder-uploader.php?confirm=url&url=" +
       encodeURI(document.getElementById("fast_image_adder_url").value) + "&post_id=" + 
       encodeURI(document.getElementById("post_id").value) + "&name=" +
	   encodeURI(document.getElementById("fast_image_adder_name").value) + "&caption=" +
       encodeURI(document.getElementById("fast_image_adder_caption").value) + "&license=" +
       encodeURI(document.getElementById("fast_image_adder_license").value) <?php if ($test_mode === true) { ?> + "&test=1"<?php } ?>;
  }
  
  function fast_image_adder_reset()
  {  
     document.getElementById("fast_image_adder_url").value = "";
     document.getElementById("fast_image_adder_name").value = "";
     document.getElementById("fast_image_adder_caption").value = "";
     document.getElementById("fast_image_adder_iframe").src = "";
     document.getElementById("fast_image_adder_div").style.display = "block";
     document.getElementById("fast_image_adder_iframe").style.display = "none";
  }
  
  // From http://stackoverflow.com/questions/905222/javascriptenter-key-press-event
  function check_keys(e)
  <?php
    if ( !current_user_can( 'upload_files' ) ) {
        wp_die( __('You do not have sufficient permissions to upload images.') );
      }
  ?>
  {
    if (e.keyCode == 13)
    {
       execute_fast_image_adder_upload();
       return false;
    }
  }
  </script>

  <div style="position:absolute;"><img id="fast_image_adder_loading_icon" src="<?php echo WP_PLUGIN_URL; ?>/fast-image-adder/loading.gif" style="display:none"></div>  
  <iframe id="fast_image_adder_iframe" style="width:100%; height:100px; display:none; margin:0; padding:0" scrolling="no" src=""></iframe>
  <div id="fast_image_adder_div" style="width:100%; height:100px; padding-top:4px; display:block">
    <div style="padding-top:4px; width:40%; float:left" id="fast_image_adder_div">
     URL of image:  
     <?php  if ($test_mode === true) { ?> <span style="color:#800000">(test mode, will not actually upload)</span><?php } ?>
     <br />
     <input type="text" id="fast_image_adder_url" name="fast_image_adder_url" tabindex="117" style="width:98%">
    </div>
    <div style="padding-top:4px; width:15%; float:left;" id="fast_image_adder_div">
     Name of image:  <br />
     <input type="text" id="fast_image_adder_name" name="fast_image_adder_name" onkeypress="return check_keys(event);" tabindex="118" style="width:98%">
    </div>
    <div style="padding-top:4px; width:15%; float:left;" id="fast_image_adder_div">
     Caption of image:  <br />
     <input type="text" id="fast_image_adder_caption" name="fast_image_adder_caption" onkeypress="return check_keys(event);" tabindex="119" style="width:98%">
    </div>
    <div style="padding-top:4px; float:left;" id="fast_image_adder_div">
     License:<br />
        <select name="fast_image_adder_license"  tabindex="120" id = "fast_image_adder_license">
          <option value="none">Select License</option>
          <option value="by">Attribution</option>
          <option value="by-nd">Attribution-NoDerivs</option>
          <option value="by-nc-nd">Attribution-NonCommercial-NoDerivs</option>
          <option value="by-nc">Attribution-NonCommercial</option>
          <option value="by-nc-sa">Attribution-NonCommercial-ShareAlike</option>
          <option selected value="by-sa">Attribution-ShareAlike</option>
        </select>
    </div>
    <div style="padding-top:4px; width:5%; float:left;" id="fast_image_adder_div">
       <br />
       <input type="hidden" name="post_id" id="post_id" value="<?php echo($post->ID);?>">
       <input type="button"  id="fast_image_adder_button" 
         onclick="execute_fast_image_adder_upload();" tabindex="121"  value="Upload"><br />
    </div>
    <div style="float:right">
      <a href="javascript:fast_image_adder_reset();" style="text-decoration:underline" onclick="fast_image_adder_reset();">Reset this form</a>
    </div>
    </div>
  
  <?php  
    
}

function fast_image_adder_convert($input)
{
   if (strpos($input,"[ ]") !== false)
   {
     $output = "<form>" . nl2br(preg_replace("/\[ \]/",
       "<input type=" . '"' . "checkbox" . '"' . ">",$input)) . "</form>";
   }
   else
   {
     $output = $input;
   }
   
   return $output;
}

/* Prints the edit form for pre-WordPress 2.5 post/page */
function fastimageadder_old_custom_box() {

  echo '<div class="dbx-b-ox-wrapper">' . "\n";
  echo '<fieldset id="fastimageadder_fieldsetid" class="dbx-box">' . "\n";
  echo '<div class="dbx-h-andle-wrapper"><h3 class="dbx-handle">' . 
        __( 'Fast Image Adder', 'fastimageadder_textdomain' ) . "</h3></div>";   
   
  echo '<div class="dbx-c-ontent-wrapper"><div class="dbx-content">';

  // output editing form

  fastimageadder_inner_custom_box();

  // end wrapper

  echo "</div></div></fieldset></div>\n";
}


?>
